Struct rgbds_obj::Section

source ·
pub struct Section { /* private fields */ }
A section definition.

Implementations

source

impl Section

source

pub fn name(&self) -> &[u8]

The section’s name. As with all names pulled from object files, this is not guaranteed to be valid UTF-8.

source

pub fn size(&self) -> u32

The section’s size.

source

pub fn type_data(&self) -> &SectionType

The section’s memory type, including data, if any.

source

pub fn modifier(&self) -> SectionMod

The section’s modifier (regular, union, etc.).

source

pub fn org(&self) -> Option<u32>

The address at which the section was fixed, or None if left floating.

source

pub fn bank(&self) -> Option<u32>

The bank the section was assigned, or None if left floating.

source

pub fn align(&self) -> u8

The section’s alignment, in bits. 0 if not specified.

source

pub fn align_ofs(&self) -> u32

The section’s alignment offset.